@@ -1,10 +1,10 @@
-__version__="2023.3.231113"
+__version__="2023.3.231211"
 __author__ ="Ludwig Corales M. dexsys@gmail.com"
 __all__=['ClearCrt','CleanText','Color','logs','ProgressBar','Table',
-         '_PRUEBA','_TIPOEJECUCION','PrintError','Cronometro','ImportarHojasXLSX','emailSender','Box','toVars','GenerateQuery']
+         '_PRUEBA','_TIPOEJECUCION','PrintError','Cronometro','ImportarHojasXLSX','Box','toVars','GenerateQuery']
 
 #,'','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','']from .Funciones import leer_pdf
 
 from .libPy2023_l import ClearCrt,CleanText,Color,logs,ProgressBar,Table,\
          _PRUEBA,_TIPOEJECUCION,PrintError,Cronometro,ImportarHojasXLSX,\
-         emailSender,Box,toVars,GenerateQuery
\ No newline at end of file
+         Box,toVars,GenerateQuery
\ No newline at end of file
