@@ -12,12 +12,12 @@ import sys
 
 import keyboard
 
-import smtplib,ssl
-from email.mime.multipart import MIMEMultipart
-from email.mime.base import MIMEBase
-from email.mime.text import MIMEText
-from email.utils import COMMASPACE
-from email import encoders
+#import smtplib,ssl
+#from email.mime.multipart import MIMEMultipart
+#from email.mime.base import MIMEBase
+#from email.mime.text import MIMEText
+#from email.utils import COMMASPACE
+#from email import encoders
 import sys
 
 def print_there(x, y, text):
@@ -406,125 +406,6 @@ def ImportarHojasXLSX(Ruta,Archivo,Hoja,Encabezados=0,AgregaOrigen=True,Mensajes
         if Mensajes:
             print(f"N° Filas Filtradas :{len(df)}\tDelta: {Ahora.Delta()}")
     return df
-"""
-if os.name=="nt":
-    def EnviarCorreoAdjunto(destinatario='lcorales', Titulo="@Python - Correos Automaticos", copy=None, mensaje=None, adjunto=None, html=False):
-        #### NOTA:
-        ####      Recordar que tanto los destinatarios como los en copia se separan con ;
-        ####      Este proceso funciona sin problemas para enviar desde Outlook sin pasar credenciales (talvez solo si esta uno logeado)
-        ol = client.Dispatch("Outlook.Application")
-        mail = ol.CreateItem(0)
-        mail.To = destinatario
-        mail.Subject = Titulo
-        mail.Importance= 2
-
-        if not copy is None:
-            mail.CC = copy
-
-        if html:
-            if not mensaje is None:
-                mail.HTMLBody = mensaje
-        else:
-            if not mensaje is None:
-                mail.Body = mensaje
-
-        if not adjunto is None:
-            mail.Attachments.Add(adjunto)
-
-        mail.Send()
-"""
-
-def emailSender(xTo ,Asunto="TEST", xBody="Hola Mundo",xServer="Outlook",adjunto=""):
-    """
-    emailSender : Permite enviar correos con adjuntos si se requiere.
-    @parameters :
-        xTo     : Destinatario(s), si es mas de uno se debe separar con ';'
-        Asunto  : Texto del Asunto o referencia del mensaje.
-        xBody   : Texto del cuerpo principal del Mensaje, texto plano o HTML
-        xServer : Servicio de correo que se utilizara, ya sea "Outlook" o "gmail"
-        adjunto : Archivo en cualquier formato que se enviara como adjunto.
-    """
-    # Define email addresses to use
-    #xServer="gmail"
-    xTo=xTo.split(";")
-    for addr_to in xTo:
-        # User_email esta definido al inicio del archivo....
-        if True:
-            User_email=USER_CLB #"lcorales@colbun.cl"
-            PassWord=PASS_CLB   #"LvIj202108*"
-        else:
-            User_email="notificador@colbun.cl"
-            PassWord="notificador"
-
-        addr_from = 'dexsys@gmail.com' if xServer=="gmail" else User_email
-
-        smtp_server='smtp.gmail.com'   if xServer=="gmail" else 'smtp-mail.outlook.com' #'smtp.office365.com' # #'smtp.office365.com' # # #'smtp-mail.outlook.com'
-        smtp_port   = 587  #25
-
-        smtp_user   = 'dexsys@gmail.com' if xServer=="gmail" else User_email
-        smtp_pass   = 'ffsgunnbyrqdsfgk' if xServer=="gmail" else PassWord
-
-        # Construct email
-        msg = MIMEMultipart('alternative')
-        msg['To'] = addr_to
-        msg['From'] = addr_from
-        msg['Subject'] = Asunto
-
-        # Create the body of the message (a plain-text and an HTML version).
-        #text = "This is a test message.\nText and html."
-
-        # Record the MIME types of both parts - text/plain and text/html.
-        #part1 = MIMEText(text, 'plain')
-        part2 = MIMEText(xBody, 'html')
-        if not adjunto=="":
-            xFile1 = MIMEBase('application', "octet-stream")
-    #       I have a CSV file named `attachthisfile.csv` in the same directory that I'd like to attach and email
-            xFile1.set_payload(open(adjunto, "rb").read())
-            encoders.encode_base64(xFile1)
-            xFile=os.path.basename(adjunto)
-            xFile1.add_header('Content-Disposition', f"attachment; filename={xFile}")
-            msg.attach(xFile1)
-
-        # Attach parts into message container.
-        # According to RFC 2046, the last part of a multipart message, in this case
-        # the HTML message, is best and preferred.
-
-        msg.attach(part2)
-
-        # Send the message via an SMTP server
-        try:
-
-            s = smtplib.SMTP(host=smtp_server, port=smtp_port)
-            #context = ssl.create_default_context()
-            # only TLSv1 or higher
-            #_DEFAULT_CIPHERS = ('ECDH+AESGCM:DH+AESGCM:ECDH+AES256:DH+AES256:ECDH+AES128:DH+AES:ECDH+HIGH:DH+HIGH:ECDH+3DES:DH+3DES:RSA+AESGCM:RSA+AES:RSA+HIGH:RSA+3DES:!aNULL:!eNULL:!MD5')
-
-            #s = smtplib.SMTP(host, port=port)
-
-            # only TLSv1 or higher
-            context = ssl.SSLContext(ssl.PROTOCOL_SSLv23)
-            context.options |= ssl.OP_NO_SSLv2
-            context.options |= ssl.OP_NO_SSLv3
-
-            #context.set_ciphers(_DEFAULT_CIPHERS)
-            #context.set_default_verify_paths()
-            #context.verify_mode = ssl.CERT_REQUIRED
-            s.ehlo()
-            if s.starttls(context=context)[0] != 220:
-                return False # cancel if connection is not encrypted
-            s.ehlo()
-            #smtp_server.login(user, password)
-            #print(f"User:{smtp_user} | Pass:{smtp_pass}")
-            s.login(smtp_user,smtp_pass)
-            s.sendmail(addr_from, addr_to, msg.as_string())
-            s.quit()
-
-        except Exception as e:
-            print("Error Inesperado: ", sys.exc_info()[0])
-            print(e)
-            print(EnvironmentError)
-            print("ERROR ----> Se produjo un Error al tratar de enviar el correo, cheque, la configuracion smtp.")
-            ErroresCorreos=1
 
 def Box(Texto=""):
     xAncho=len(CleanText( Texto))
@@ -572,4 +453,5 @@ def MessageBox(Texto="Falta el Mensaje",Opciones="SN"):
         Tecla=keyboard.read_key().upper()
         if Tecla in Opciones:
             break
-    return Tecla
\ No newline at end of file
+    return Tecla
+
